@@ -14,6 +14,8 @@
 
 // This tests a conforming extension
 
+// UNSUPPORTED: c++98, c++03
+
 #include <queue>
 #include <cassert>
 
@@ -21,10 +23,8 @@
 
 int main()
 {
-#if __has_feature(cxx_noexcept)
     {
         typedef std::queue<MoveOnly> C;
         static_assert(std::is_nothrow_move_constructible<C>::value, "");
     }
-#endif
 }
