@@ -14,6 +14,8 @@
 
 // This tests a conforming extension
 
+// UNSUPPORTED: c++98, c++03
+
 #include <stack>
 #include <cassert>
 
@@ -21,11 +23,9 @@
 
 int main()
 {
-#if __has_feature(cxx_noexcept)
     {
         typedef std::stack<MoveOnly> C;
         C c1, c2;
         static_assert(noexcept(swap(c1, c2)), "");
     }
-#endif
 }
