@@ -17,6 +17,12 @@
 #include <array>
 #include <cassert>
 
+#include "test_macros.h"
+
+// std::array is explicitly allowed to be initialized with A a = { init-list };.
+// Disable the missing braces warning for this reason.
+#include "disable_missing_braces_warning.h"
+
 int main()
 {
     {
@@ -28,7 +34,7 @@ int main()
         assert(r1 == 1);
         r1 = 5.5;
         assert(c[0] == 5.5);
-        
+
         C::reference r2 = c.back();
         assert(r2 == 3.5);
         r2 = 7.5;
@@ -45,12 +51,12 @@ int main()
         assert(r2 == 3.5);
     }
 
-#if _LIBCPP_STD_VER > 11 
+#if TEST_STD_VER > 11
     {
         typedef double T;
         typedef std::array<T, 3> C;
         constexpr C c = {1, 2, 3.5};
-        
+
         constexpr T t1 = c.front();
         static_assert (t1 == 1, "");
 
