@@ -29,7 +29,7 @@ int main()
     assert(d[2] == 5);
     assert(d[3] == 6);
     }
-#if __cplusplus >= 201103L
+#if TEST_STD_VER >= 11
     {
     std::deque<int, min_allocator<int>> d({3, 4, 5, 6}, min_allocator<int>());
     assert(d.get_allocator() == min_allocator<int>());
